# tcex - ThreatConnect Exchange App Framework

The ThreatConnect&trade; TcEx App Framework provides functionality for writing ThreatConnect Exchange Apps.

## Requirements

 * arrow (https://pypi.python.org/pypi/arrow)
 * backports.cached-property (https://pypi.org/project/backports.cached-property/)
 * colorama (https://pypi.python.org/pypi/colorama)
 * future (https://pypi.org/project/future/)
 * inflect (https://pypi.python.org/pypi/inflect)
 * jmespath (https://pypi.org/project/jmespath/)
 * paho-mqtt (https://pypi.org/project/paho-mqtt/)
 * pyaes (https://pypi.org/project/pyaes/)
 * pydantic (https://pypi.org/project/pydantic/)
 * python-dateutil (https://pypi.python.org/pypi/python-dateutil)
 * redis (https://pypi.python.org/pypi/redis)
 * requests (http://docs.python-requests.org/en/latest)
 * semantic_version (https://pypi.org/project/semantic-version/)
 * stdlib-list (https://pypi.org/project/stdlib-list/)
 * tinydb (https://pypi.python.org/pypi/tinydb)
 * typer (https://pypi.python.org/pypi/typer)
 * wrapt (https://pypi.org/project/wrapt/)

### Development Requirements

 * bandit (https://pypi.org/project/bandit/)
 * black (https://pypi.org/project/black/)
 * codespell (https://pypi.org/project/codespell/)
 * deepdiff (https://pypi.org/project/deepdiff/)
 * flake8 (https://pypi.org/project/flake8/)
 * isort (https://pypi.org/project/isort/)
 * mako (https://pypi.org/project/mako/)
 * pre-commit (https://pypi.org/project/pre-commit/)
 * pydocstyle (https://pypi.org/project/pydocstyle/)
 * pylint (https://pypi.org/project/pylint/)
 * pytest (https://pypi.org/project/pytest/)
 * pytest-cov (https://pypi.org/project/pytest-cov/)
 * pytest-html (https://pypi.org/project/pytest-html/)
 * pytest-xdist (https://pypi.org/project/pytest-xdist/)
 * pyupgrade (https://pypi.org/project/pyupgrade/)

## Installation

**Using pip**

```
pip install tcex
pip install tcex[development]
```

**Manually**

```
cd tcex
python setup.py install --force
```

## Documentation

https://threatconnect.readme.io/docs/overview

## Release Notes

https://threatconnect.readme.io/docs/release-notes

## Contact

If you have any questions, bugs, or requests please contact support@threatconnect.com
